cansig.run package
==================

Submodules
----------

cansig.run.download module
--------------------------

.. automodule:: cansig.run.download
   :members:
   :undoc-members:
   :show-inheritance:

cansig.run.integration module
-----------------------------

.. automodule:: cansig.run.integration
   :members:
   :undoc-members:
   :show-inheritance:

cansig.run.pipeline module
--------------------------

.. automodule:: cansig.run.pipeline
   :members:
   :undoc-members:
   :show-inheritance:

cansig.run.postprocessing module
--------------------------------

.. automodule:: cansig.run.postprocessing
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cansig.run
   :members:
   :undoc-members:
   :show-inheritance:
